[PC-BSD Commits] r18858 - pcbsd-projects/PCDM
svn at pcbsd.org
svn at pcbsd.org
Wed Sep 5 09:14:09 PDT 2012
Author: kenmoore
Date: 2012-09-05 16:14:09 +0000 (Wed, 05 Sep 2012)
New Revision: 18858
Modified:
pcbsd-projects/PCDM/main.cpp
Log:
Fix up the PCDM x startup loop
Modified: pcbsd-projects/PCDM/main.cpp
===================================================================
--- pcbsd-projects/PCDM/main.cpp 2012-09-05 16:02:27 UTC (rev 18857)
+++ pcbsd-projects/PCDM/main.cpp 2012-09-05 16:14:09 UTC (rev 18858)
@@ -58,7 +58,7 @@
}
splash.show();
-
+ Backend::log("Starting up PCDM interface");
PCDMgui w;
//Set the proper size on the Application
@@ -97,11 +97,15 @@
break;
}
*/
-
- //Check for whether to stay in the restart loop or not
+ // Startup the desktop environment if possible
+ Backend::log("Trying to start up the desired desktop environment");
+ Backend::startXSession();
+ // Check for whether to stay in the restart loop or not
if(Debug_Mode){
runRestartLoop = FALSE;
}
+ if(runRestartLoop){ Backend::log("Restarting PCDM"); }
+ else{ Backend::log("PCDM shutting down"); }
}
return returnCode;
}
More information about the Commits
mailing list